==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/COLUMNDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour COLUMNDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="COLUMNDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COLUMN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COLUMNLENGTH"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPECODE"/>
 *         &lt;element name="NULLABLE" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "COLUMNDETAILS_Type", propOrder = {
    "column",
    "columnlength",
    "typecode",
    "nullable"
})
public class COLUMNDETAILS_Type {

    @XmlElement(name = "COLUMN", required = true)
    protected String column;
    @XmlElement(name = "COLUMNLENGTH", required = true)
    protected String columnlength;
    @XmlElement(name = "TYPECODE", required = true)
    protected String typecode;
    @XmlElement(name = "NULLABLE", required = true)
    protected String nullable;

    /**
     * Obtient la valeur de la propriété column.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLUMN() {
        return column;
    }

    /**
     * Définit la valeur de la propriété column.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLUMN(String value) {
        this.column = value;
    }

    /**
     * Obtient la valeur de la propriété columnlength.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLUMNLENGTH() {
        return columnlength;
    }

    /**
     * Définit la valeur de la propriété columnlength.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLUMNLENGTH(String value) {
        this.columnlength = value;
    }

    /**
     * Obtient la valeur de la propriété typecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTYPECODE() {
        return typecode;
    }

    /**
     * Définit la valeur de la propriété typecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTYPECODE(String value) {
        this.typecode = value;
    }

    /**
     * Obtient la valeur de la propriété nullable.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNULLABLE() {
        return nullable;
    }

    /**
     * Définit la valeur de la propriété nullable.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNULLABLE(String value) {
        this.nullable = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/COLUMNDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for COLUMNDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="COLUMNDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COLUMN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COLUMNLENGTH"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPECODE"/>
 *         &lt;element name="NULLABLE" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "COLUMNDETAILS_Type", propOrder = {
    "column",
    "columnlength",
    "typecode",
    "nullable"
})
public class COLUMNDETAILS_Type {

    @XmlElement(name = "COLUMN", required = true)
    protected String column;
    @XmlElement(name = "COLUMNLENGTH", required = true)
    protected String columnlength;
    @XmlElement(name = "TYPECODE", required = true)
    protected String typecode;
    @XmlElement(name = "NULLABLE", required = true)
    protected String nullable;

    /**
     * Gets the value of the column property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLUMN() {
        return column;
    }

    /**
     * Sets the value of the column property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLUMN(String value) {
        this.column = value;
    }

    /**
     * Gets the value of the columnlength property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLUMNLENGTH() {
        return columnlength;
    }

    /**
     * Sets the value of the columnlength property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLUMNLENGTH(String value) {
        this.columnlength = value;
    }

    /**
     * Gets the value of the typecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTYPECODE() {
        return typecode;
    }

    /**
     * Sets the value of the typecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTYPECODE(String value) {
        this.typecode = value;
    }

    /**
     * Gets the value of the nullable property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNULLABLE() {
        return nullable;
    }

    /**
     * Sets the value of the nullable property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNULLABLE(String value) {
        this.nullable = value;
    }

}
